Reading an ASDF file: its tree, and the data in its binary blocks.
Structs
- Reader
- An open ASDF file.
Enums
- Checksum
Status - The outcome of verifying a block’s checksum.
Reading an ASDF file: its tree, and the data in its binary blocks.